#[repr(transparent)]pub struct Reverse<T>(pub T);Expand description
A helper struct for reverse ordering.
This struct is a helper to be used with functions like Vec::sort_by_key and
can be used to reverse order a part of a key.
Examples
Tuple Fields
0: TTrait Implementations
1.19.0 · Sourceimpl<T: Clone> Clone for Reverse<T>
impl<T: Clone> Clone for Reverse<T>
Sourcefn clone(&self) -> Reverse<T>
fn clone(&self) -> Reverse<T>
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Returns a duplicate of the value. Read more
Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Performs copy-assignment from
source. Read more1.19.0 · Sourceimpl<T: Hash> Hash for Reverse<T>
impl<T: Hash> Hash for Reverse<T>
1.19.0 (const: unstable) · Sourceimpl<T: Ord> Ord for Reverse<T>
impl<T: Ord> Ord for Reverse<T>
Sourcefn cmp(&self, other: &Reverse<T>) -> Ordering
fn cmp(&self, other: &Reverse<T>) -> Ordering
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Compares and returns the maximum of two values. Read more
1.19.0 (const: unstable) · Sourceimpl<T: PartialEq> PartialEq for Reverse<T>
impl<T: PartialEq> PartialEq for Reverse<T>
1.19.0 (const: unstable) · Sourceimpl<T: PartialOrd> PartialOrd for Reverse<T>
impl<T: PartialOrd> PartialOrd for Reverse<T>
Sourcefn partial_cmp(&self, other: &Reverse<T>) -> Option<Ordering>
fn partial_cmp(&self, other: &Reverse<T>) -> Option<Ordering>
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Sourcefn lt(&self, other: &Self) -> bool
fn lt(&self, other: &Self) -> bool
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Sourcefn le(&self, other: &Self) -> bool
fn le(&self, other: &Self) -> bool
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
impl<T: Copy> Copy for Reverse<T>
impl<T: Eq> Eq for Reverse<T>
impl<T> StructuralPartialEq for Reverse<T>